@@ -87,7 +87,7 @@ class curse():
                         if "," in arg:
                             msg = f"One of those words are already in the list."
                         else:
-                            msg = f"{word} is already in the list."
+                            msg = f"That word is already in the list."
                         await ctx.send(msg, delete_after=5)
                         return
             word = word.replace(" ", "")
@@ -574,6 +574,9 @@ class rr():
             number = 0
             for x in emoji_list:
                 role = role_list[number]
+                if "@" not in role:
+                    await ctx.send("Invalid Role. Please read https://sites.google.com/view/dpys/reaction-roles", delete_after=15)
+                    return
                 role = role.replace("<", "")
                 role = role.replace(">", "")
                 role = role.replace("@", "")
@@ -585,6 +588,9 @@ class rr():
             await db.close()
         else:
             await msg.add_reaction(emoji)
+            if "@" not in role:
+                await ctx.send("Invalid Role. Please read https://sites.google.com/view/dpys/reaction-roles", delete_after=15)
+                return
             role = role.replace("<", "")
             role = role.replace(">", "")
             role = role.replace("@", "")
@@ -618,35 +624,27 @@ class rr():
                     await member.remove_roles(role)
         await db.close()
 
-    async def clear_all(ctx, dir):
+    async def clear(message, dir):
         os.chdir(dir)
-        guild = str(ctx.guild.id)
+        id = str(message.id)
+        guild = str(message.guild.id)
         db = await aiosqlite.connect("rr.db")
-        await db.execute("DELETE FROM rr WHERE guild = ?", (guild,))
-        await db.commit()
+        async with db.execute("SELECT msg_id FROM rr WHERE guild = ?", (guild,)) as cursor:
+            async for entry in cursor:
+                msg_id = entry[0]
+                if id == msg_id:
+                    await db.execute("DELETE FROM rr WHERE msg_id = ? and guild = ?", (msg_id,guild))
+                    await db.commit()
+                    return
         await db.close()
-        await ctx.send("Delted all reaction role info for this server.", delete_after=7)
 
-    async def clear_one(ctx, dir, message_id):
-        os.chdir(dir)
-        guild = str(ctx.guild.id)
-        message_id = str(message_id)
-        db = await aiosqlite.connect("rr.db")
-        message_id = message_id.replace(" ", "")
-        message_id = message_id.split(",")
-        for x in message_id:
-            await db.execute("DELETE FROM rr WHERE guild = ? and msg_id = ?", (guild,x))
-        await db.commit()
-        await db.close()
-        message_id = ", ".join(message_id)
-        await ctx.send(f"Delted reaction role info for {message_id}", delete_after=7)
     async def display(ctx, dir):
-        limit = False
+        limit = "limit"
         os.chdir(dir)
         guild = str(ctx.guild.id)
         db = await aiosqlite.connect("rr.db")
         embed = discord.Embed(title="Reaction Roles", color = 0x0000FF)
-        async with db.execute("SELECT msg_id FROM rr GROUP BY msg_id") as cursor:
+        async with db.execute("SELECT msg_id FROM rr  WHERE guild = ? GROUP BY msg_id", (guild,)) as cursor:
             number = 0
             async for entry in cursor:
                 number += 1
@@ -665,19 +663,20 @@ class rr():
                             channel = channel.mention
                         except:
                             channel = "#deleted-channel"
-                        msg += f"Emoji: {emoji} Role: {role} Channel: {channel} Message ID: {msg_id}\n"
-                        msg_limit += f"Channel: {channel} Message ID: {msg_id}\n"
+                        msg += f"Emoji: {emoji} Role: {role}\n"
+                    msg_limit += f"Channel: {channel} Message ID: {msg_id}\n"
+                    msg += f"Channel: {channel} Message ID: {msg_id}\n"
                 if len(msg) > 1010:
                     embed.add_field(name=f"Reaction Role #{number}", inline=False, value=msg_limit)
-                    limit = True
+                    limit = "True"
                 else:
                     embed.add_field(name=f"Reaction Role #{number}", inline=False, value=msg)
         if number > 0:
-            if limit == False:
+            if limit == "limit":
                 embed.set_footer(text=f"Total Reaction Roles | {number}")
             else:
                 embed.set_footer(text=f"Total Reaction Roles | {number}")
-                await ctx.reply("One of your reaction roles went over the Discord limit. It will still work perfectly but only essintial data will be displayed in this command to save space.", delete_after=10)
+                await ctx.reply("One of your reaction roles went over the Discord limit. It will still work perfectly but only essential data will be displayed in this command to save space.", delete_after=10)
             await ctx.send(embed=embed, reference= ctx.message.reference or ctx.message)
         else:
             await ctx.send("There are no reaction roles in this server.", delete_after=5)
